{ pkgs, lib, ... }:
let
  hx-src = pkgs.helix.src;
  kts-src = pkgs.kak-tree-sitter.src;
  inherit (pkgs) fetchFromGitHub;
in
with pkgs.tree-sitter-grammars;
{
  xdg.configFile."kak-tree-sitter/config.toml".text =
    lib.foldlAttrs
      (
        acc: name: vals:
        acc
        + ''
          [language.${name}.grammar.source.local]
          path = "${vals.parser}/parser"
          [language.${name}.grammar]
          compile = "cc"
          compile_args = ["-c", "-fpic", "../scanner.c", "../parser.c", "-I", ".."]
          compile_flags = ["-O3"]
          link = "cc"
          link_args = ["-shared", "-fpic", "scanner.o", "parser.o", "-o", "typescript.so"]
          link_flags = ["-O3"]
          [language.${name}.queries.source.local]
          path = "${vals.queries or hx-src}/runtime/queries/${vals.queryName or name}"
          [language.${name}.queries]
          path = "runtime/queries/${vals.queryName or name}"
        ''
      )
      ""
      {
        c.parser = tree-sitter-c;
        rust.parser = tree-sitter-rust;
        nix.parser = tree-sitter-nix;
        nu.parser = tree-sitter-nu;
        python.parser = tree-sitter-python;
        javascript.parser = tree-sitter-javascript;
        jsx.parser = tree-sitter-javascript;
        scss.parser = tree-sitter-scss;
        css.parser = tree-sitter-css;
        toml.parser = tree-sitter-toml;
        yaml.parser = tree-sitter-yaml;
        json.parser = tree-sitter-json;
        html.parser = tree-sitter-html;

        typescript = {
          parser = tree-sitter-typescript.overrideAttrs (old: {
            src = fetchFromGitHub {
              owner = "tree-sitter";
              repo = "tree-sitter-typescript";
              rev = "b1bf4825d9eaa0f3bdeb1e52f099533328acfbdf";
              hash = "sha256-oZKit8kScXcOptmT2ckywL5JlAVe+wuwhuj6ThEI5OQ=";
            };
          });
          queries = kts-src;
        };
        tsx = {
          parser = tree-sitter-tsx;
          queries = kts-src;
        };
      };
}
